"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.sanitizeOnSubmitResult = exports.sanitizeValidationResult = void 0;

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread"));

var _typeof2 = _interopRequireDefault(require("@babel/runtime/helpers/typeof"));

var React = _interopRequireWildcard(require("react"));

var sanitizeValidationResult = function sanitizeValidationResult(result) {
  var forceError = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
  var validation = sanitizeValidationResult0(result);

  if (forceError) {
    validation.validated = "error";
  }

  return validation;
};

exports.sanitizeValidationResult = sanitizeValidationResult;

var sanitizeValidationResult0 = function sanitizeValidationResult0(result) {
  if (result === null || result === undefined || result === "") return sanitizeResultNull(result);
  if (result === "timeout") return sanitizeTimeout(result);
  if (typeof result === "string" || React.isValidElement(result) || Array.isArray(result)) return sanitizeResultReactElement(result);
  if (result instanceof Error) return sanitizeResultError(result);
  if ((0, _typeof2.default)(result) === "object") return sanitizeResultObject(result);
  if (typeof result === "boolean") return sanitizeResultBoolean(result);
  return sanitizeResultInvalid(result);
};

var sanitizeOnSubmitResult = function sanitizeOnSubmitResult(result) {
  var forceError = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;

  if (!Array.isArray(result)) {
    result = [result];
  }

  return result.map(function (single) {
    var validation = sanitizeValidationResult(single, forceError);
    return (0, _objectSpread2.default)({}, validation, {
      key: single && typeof single.key === "string" && single.key || null
    });
  });
};

exports.sanitizeOnSubmitResult = sanitizeOnSubmitResult;

var sanitizeResultObject = function sanitizeResultObject(object) {
  return VALIDATION(sanitizeResultObjectGetValidated(object), object.message || object.name || null);
};

var sanitizeResultError = function sanitizeResultError(result) {
  return FAIL_VALIDATION(result.message || result.stack || result.name);
};

var sanitizeResultBoolean = function sanitizeResultBoolean(result) {
  return result ? PASS_VALIDATION() : FAIL_VALIDATION();
};

;

var sanitizeResultNull = function sanitizeResultNull() {
  return PASS_VALIDATION();
};

var sanitizeTimeout = function sanitizeTimeout() {
  return FAIL_VALIDATION("timeout");
};

var sanitizeResultInvalid = function sanitizeResultInvalid(result) {
  console.warn("[react-formilicious] Invalid form validation result", result);
  return FAIL_VALIDATION();
};

var sanitizeResultReactElement = function sanitizeResultReactElement(react) {
  if (!react) return PASS_VALIDATION();
  if (Array.isArray(react) && react.length === 0) return PASS_VALIDATION();
  return FAIL_VALIDATION(react);
}; // Objects can have the shorthand "error" property.


var sanitizeResultObjectGetValidated = function sanitizeResultObjectGetValidated(_ref) {
  var validated = _ref.validated,
      error = _ref.error,
      message = _ref.message,
      name = _ref.name;

  switch (validated) {
    case "ok":
      return "ok";

    case "hint":
      return "hint";

    case "error":
      return "error";

    case undefined:
      {
        if (error !== undefined && error) return "error";
        if (error !== undefined && !error) return "ok";
        if (message || name) return "error";
        return "ok";
      }

    default:
      return "error";
  }
};

var VALIDATION = function VALIDATION() {
  var validated = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : "error";
  var message = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
  return {
    validated: validated,
    message: message
  };
};

var PASS_VALIDATION = function PASS_VALIDATION() {
  var message = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  return VALIDATION("ok", message);
};

var FAIL_VALIDATION = function FAIL_VALIDATION() {
  var message = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  return VALIDATION("error", message);
};