"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _typeof2 = _interopRequireDefault(require("@babel/runtime/helpers/typeof"));

var defaultLocale = {
  'string.minmax': function stringMinmax(min, max, is) {
    return "The value entered must be between ".concat(min, " and ").concat(max, " characters long. (It has ").concat(is, " ").concat(is === 1 ? "character" : "characters", ")");
  },
  'string.min': function stringMin(min, max, is) {
    return "The value entered must have at least ".concat(min, " ").concat(min === 1 ? "character" : "characters", ". (It has ").concat(is, " ").concat(is === 1 ? "character" : "characters", ")");
  },
  'string.max': function stringMax(min, max, is) {
    return "The value entered may not be longer than ".concat(max, " ").concat(max === 1 ? "character" : "characters", ". (It has ").concat(is, " ").concat(is === 1 ? "character" : "characters", ")");
  },
  'number.minmax': function numberMinmax(min, max, is) {
    return "The number must be between ".concat(min, " and ").concat(max, ".");
  },
  'number.min': function numberMin(min, max, is) {
    return "The number must be larger than ".concat(min, ".");
  },
  'number.max': function numberMax(min, max, is) {
    return "The number may not be smaller than ".concat(max, ".");
  },
  'object.minmax': function objectMinmax(min, max, is) {
    return "The value must have between ".concat(min, " and ").concat(max, " entries. (It has ").concat(is, " ").concat(is === 1 ? "entry" : "entries", ")");
  },
  'object.min': function objectMin(min, max, is) {
    return "The value must have more than ".concat(min, " ").concat(min === 1 ? "entry" : "entries", ". (It has ").concat(is, " ").concat(is === 1 ? "entry" : "entries", ")");
  },
  'object.max': function objectMax(min, max, is) {
    return "The value may not have less than ".concat(max, " ").concat(max === 1 ? "entry" : "entries", ". (It has ").concat(is, " ").concat(is === 1 ? "entry" : "entries", ")");
  }
};

var range = function range(_ref) {
  var min = _ref.min,
      max = _ref.max;
  var locale = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultLocale;
  return function (value) {
    switch ((0, _typeof2.default)(value)) {
      case "string":
        return {
          validated: numberInRange(min, max, value.length) ? "ok" : "error",
          message: locale[localeKey("string", min, max)](min, max, value.length)
        };

      case "number":
        return {
          validated: numberInRange(min, max, value) ? "ok" : "error",
          message: locale[localeKey("number", min, max)](min, max, value)
        };

      case "object":
        {
          var keyCount = Object.keys(value).length;
          return {
            validated: numberInRange(min, max, keyCount) ? "ok" : "error",
            message: locale[localeKey("object", min, max)](min, max, keyCount)
          };
        }

      default:
        {
          console.error("[react-formilicious] Cannot validate the given value as a range", value);
          return {
            validated: "error",
            message: null
          };
        }
    }
  };
};

var localeKey = function localeKey(prefix, min, max) {
  var localeKey = prefix + "." + (min !== undefined ? "min" : "") + (max !== undefined ? "max" : "");
  return localeKey;
};

var numberInRange = function numberInRange(min, max, number) {
  if (min !== undefined && number < min) return false;
  if (max !== undefined && number > max) return false;
  return true;
};

var _default = range;
exports.default = _default;